// Written by Dr. YIP Chi Lap [Beta]
//   for Talk on "DIY Earthquake Detector: The software side" 
//   Earthquake Detector Design Competition
//   Faculty of Engineering, The University of Hong Kong, 2016.

// Specify that video processing library is to be used.
import processing.video.*;

// This is made globally accessible representing the camera.
Capture camera;

// This function is called when the program starts to run.
void setup() {
  // Sets the size of the display window.
  size(640, 480, P2D);
  // Creates the camera object.
  camera = new Capture(this,width,height);
  // Starts the camera for capturing.
  camera.start();
  // This make the display pixels available
  //   for manipulation in the pixels[] array.
  loadPixels();
}

// This function is called automatically
//   whenever the display needs to be refreshed.
void draw() {
  if (camera.available()) {
    // Read the captured frame from camera.
    camera.read();
    // Make the pixels of the captured frame available for manipulation.
    camera.loadPixels();
    // Horizontally flip evey line.
    for (int y=0; y<camera.height; ++y) { // for each line
      for (int x=0;x<camera.width; ++x) { // for each horizontal position
        // Flips the screen horizontally.
        // The pixel at (x,y) is copied
        //   the pixel at (width-1-x,y) of the camera.
        // This works as there are width pixels in the y-th line,
        //   from (0,y) to (width-1,y).
        // Copying camera pixel (width-1-0,y) to screen (0,y)
        //         camera pixel (width-1-1,y) to screen (1,y)
        //         camera pixel (width-1-2,y) to screen (2,y)
        //                             :                  :
        //                             :                  :
        //         camera pixel (width-1-(width-1),y) to screen (width-1,y)
        //   effectively flips the screen horizontally.
        //
        // x-coordinate
        //  | y-coordinate
        //  |  |          colour
        //  |  |  -----------------------
        set(x, y, camera.get(width-1-x,y));
      }
    }
    // This is to tell the system that the display pixels have been modified
    //   and a redraw is needed.
    updatePixels();
  }
}
